# WorkItemMovePostModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | WorkItemId | [optional] 
**old_section_id** | **str, none_type** |  | [optional] 
**new_section_id** | **str, none_type** |  | [optional] 
**next_work_item_id** | **str, none_type** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


